## 东方财富板块成分

接口：dc_member

描述：获取东方财富板块每日成分数据，可以根据概念板块代码和交易日期，获取历史成分

限量：单次最大获取5000条数据，可以通过日期和代码循环获取

权限：用户积累6000积分可调取，具体请参阅积分获取办法







注意：本接口只限个人学习和研究使用，如需商业用途，请自行联系东方财富解决数据采购问题。

输入参数

| 名称 | 类型 | 必选 | 描述 |
| --- | --- | --- | --- |
| ts_code | str | N | 板块指数代码 |
| con_code | str | N | 成分股票代码 |
| trade_date | str | N | 交易日期（YYYYMMDD格式） |

输出参数

| 名称 | 类型 | 默认显示 | 描述 |
| --- | --- | --- | --- |
| trade_date | str | Y | 交易日期 |
| ts_code | str | Y | 概念代码 |
| con_code | str | Y | 成分代码 |
| name | str | Y | 成分股名称 |

接口示例

```python
#获取东方财富2025年1月2日的人形机器人概念板块成分列表
df = pro.dc_member(trade_date='20250102', ts_code='BK1184.DC')
```

数据示例

```python
trade_date  ts_code   con_code   name
0    20250102  BK1184.DC  002117.SZ   东港股份
```